PROGRAM_NAME='D - Demo-Hauptprogramm zum EIB-Interface'
(*   DATE:01/11/00    TIME:11:39:47    *)

DEFINE_DEVICE
  EIB  =  17 (* Device-Adresse der AXB-232++/AXC-232++ *)
  TP   = 128 (* Irgendein Bediengeraet, z.B. AXT-EL+ *)

DEFINE_CONSTANT
  Sw_Licht1    = 1 (* laufende Switch-Nummer Deckenlicht *)
  Sw_Licht2    = 2 (* laufende Switch-Nummer Pultlicht *)
  Sw_Licht3    = 3 (* laufende Switch-Nummer Pultlicht *)
  Sw_Dimmer    = 4 (* Dimmer Ein/Aus *)

  D4_Dimmer    = 1 (* relativ Dimmen *)

  B1_Dim_Set   = 1 (* Dimmer setzen *)
  B1_Dim_Val   = 2 (* Dimmer Wert *)

DEFINE_CONNECT_LEVEL
  (EIB,B1_Dim_Val,TP,1) (* Helligkeit auf Bargraph 1 anzeigen *)

DEFINE_VARIABLE
  EIB_Puffer[255]   (* Empfangspuffer der Box *)
  INTEGER EIB_Switch[255]   (* Aktuelle Werte der EIB-Switches *)
  INTEGER EIB_Dim4[255]     (* Aktuelle Werte Dim4 *)
  INTEGER EIB_1Byte[255]    (* Aktuelle Werte 1Byte *)

DEFINE_START
  CREATE_BUFFER EIB,EIB_Puffer (* Empfangspuffer verbinden *)

DEFINE_PROGRAM
(* Rueckmeldungen einlesen *)
SYSTEM_CALL 'EIB Read Standard' (EIB_Puffer,EIB_Switch,EIB_Dim4,EIB_1Byte)

(* Licht1 schalten, je ein Knopf fuer 'Ein' und 'Aus' *)
PUSH[TP,1] (* Licht1 ein *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Licht1)

PUSH[TP,2] (* Licht1 aus *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Licht1)

[TP,1] = [EIB,Sw_Licht1]     (* Rueckmeldung 'ein' *)
[TP,2] = not [EIB,Sw_Licht1] (* Rueckmeldung 'aus' *)

(* Licht2 schalten, ein Knopf schaltet zwischen 'Ein' und 'Aus' um *)
PUSH[TP,3] (* Licht2 ein/aus *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,not [EIB,Sw_Licht2],Sw_Licht2)

[TP,3] = [EIB,Sw_Licht2]     (* Rueckmeldung 'ein' *)

(* Licht3 schalten, Knopf schaltet Licht fuer 10 Sekunden an *)
PUSH[TP,4] (* Licht3 fuer 10 Sekunden an *)
  {
  CANCEL_WAIT 'Licht3'
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Licht3)
  WAIT 100 'Licht3'
    SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Licht3)
  }

[TP,4] = [EIB,Sw_Licht3]     (* Rueckmeldung 'ein' *)

(* Dimmersteuerung *)
PUSH[TP,5] (* Dimmer aus *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Dimmer)

PUSH[TP,6] (* Dimmer auf 25% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,64,B1_Dim_Set)

PUSH[TP,7] (* Dimmer auf 50% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,128,B1_Dim_Set)

PUSH[TP,8] (* Dimmer auf 75% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,192,B1_Dim_Set)

PUSH[TP,9] (* Dimmer auf 100% *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Dimmer)

[TP,5] = (EIB_1Byte[B1_Dim_Val] = 0)   (* Feedback 0% *)
[TP,6] = (EIB_1Byte[B1_Dim_Val] = 64)  (* Feedback 25% *)
[TP,7] = (EIB_1Byte[B1_Dim_Val] = 128) (* Feedback 50% *)
[TP,8] = (EIB_1Byte[B1_Dim_Val] = 192) (* Feedback 75% *)
[TP,9] = (EIB_1Byte[B1_Dim_Val] = 255) (* Feedback 100% *)

PUSH[TP,10] (* Heller *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,10,D4_Dimmer)

PUSH[TP,11] (* Dunkler *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,2,D4_Dimmer)

RELEASE[TP,10] (* Hell genug *)
RELEASE[TP,11] (* Dunkel genug *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,0,D4_Dimmer)

[TP,10] = ((EIB_Dim4[D4_Dimmer] >= 9) and (EIB_Dim4[D4_Dimmer] <= 15))
[TP,11] = ((EIB_Dim4[D4_Dimmer] >= 1) and (EIB_Dim4[D4_Dimmer] <= 7))

